@@ -6,7 +6,7 @@
  * Descr.: GNU Prolog - general header file (for users)                    *
  * Author: Daniel Diaz                                                     *
  *                                                                         *
- * Copyright (C) 1999-2015 Daniel Diaz                                     *
+ * Copyright (C) 1999-2021 Daniel Diaz                                     *
  *                                                                         *
  * This file is part of GNU Prolog                                         *
  *                                                                         *
@@ -69,15 +69,15 @@ extern "C" {
 
 #define __GNU_PROLOG__        	1
 #define __GPROLOG__           	1
-#define __GPROLOG_MINOR__     	4
-#define __GPROLOG_PATCHLEVEL__	5
-#define __GPROLOG_VERSION__   	10405
+#define __GPROLOG_MINOR__     	5
+#define __GPROLOG_PATCHLEVEL__	0
+#define __GPROLOG_VERSION__   	10500
 
 #define PROLOG_DIALECT  	"gprolog"
 #define PROLOG_NAME     	"GNU Prolog"
-#define PROLOG_VERSION  	"1.4.5"
-#define PROLOG_DATE     	"Jul  8 2020"
-#define PROLOG_COPYRIGHT	"Copyright (C) 1999-2020 Daniel Diaz"
+#define PROLOG_VERSION  	"1.5.0"
+#define PROLOG_DATE     	"Jul 16 2021"
+#define PROLOG_COPYRIGHT	"Copyright (C) 1999-2021 Daniel Diaz"
 
 #define PL_MIN_INTEGER		-1152921504606846976
 #define PL_MAX_INTEGER		1152921504606846975
@@ -297,6 +297,14 @@ PlLong Pl_Rd_Positive_Check(PlTerm term);
 
 PlLong Pl_Rd_Positive(PlTerm term);
 
+int Pl_Rd_C_Int_Check(PlTerm start_word);
+
+int Pl_Rd_C_Int(PlTerm start_word);
+
+int Pl_Rd_C_Int_Positive_Check(PlTerm start_word);
+
+int Pl_Rd_C_Int_Positive(PlTerm start_word);
+
 double Pl_Rd_Float_Check(PlTerm term);
 
 double Pl_Rd_Float(PlTerm term);
